# ASPIRED
[![Build Status](https://travis-ci.com/cylammarco/ASPIRED.svg?branch=dev)](https://travis-ci.com/cylammarco/ASPIRED)
[![Readthedocs Status](https://readthedocs.org/projects/aspired/badge/?version=latest&style=flat)](https://aspired.readthedocs.io/en/latest/)

OPTICON funded project - Automated SpectroPhotometric Image REDuction

[Documentation](https://aspired.readthedocs.io/en/latest/)
